<?php

namespace Larayellow\Newsletter\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;
use Larayellow\Newsletter\Repositories\Eloquent\Filters\NewsletterPublicFilter;
use Larayellow\Newsletter\Repositories\Eloquent\Presenters\NewsletterListPresenter;
use Larayellow\Newsletter\Interfaces\NewsletterRepositoryInterface;

class NewsletterPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(NewsletterRepositoryInterface $newsletter)
    {
        parent::__construct();
        $this->modules = $this->modules(config('larayellow.newsletter.modules'), 'newsletter', guard_url('newsletter'));
        $this->repository = $newsletter;

    }

    /**
     * Show newsletter's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(NewsletterPublicFilter::class)
            ->setPresenter(NewsletterListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('newsletter::newsletter.names'))
            ->view('newsletter::public.newsletter.index')
            ->data(compact('data', 'meta', 'modules'))
            ->output();
    }


    /**
     * Show newsletter.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();
        $modules = $this->modules;

        return $this->response->setMetaTitle($data['name'] . trans('newsletter::newsletter.name'))
            ->view('newsletter::public.newsletter.show')
            ->data(compact('data', 'modules'))
            ->output();
    }

}
