<?php

namespace Larayellow\Newsletter\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Larayellow\Newsletter\Models\Newsletter;

class NewsletterPolicy
{

    /**
     * Determine if the given user can view the newsletter.
     *
     * @param UserPolicyInterface $authUser
     * @param Newsletter $newsletter
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Newsletter $newsletter)
    {
        if ($authUser->canDo('newsletter.newsletter.view') && $authUser->isAdmin()) {
            return true;
        }

        return $newsletter->user_id == user_id() && $newsletter->user_type == user_type();
    }

    /**
     * Determine if the given user can create a newsletter.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('newsletter.newsletter.create');
    }

    /**
     * Determine if the given user can update the given newsletter.
     *
     * @param UserPolicyInterface $authUser
     * @param Newsletter $newsletter
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Newsletter $newsletter)
    {
        if ($authUser->canDo('newsletter.newsletter.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $newsletter->user_id == user_id() && $newsletter->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given newsletter.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Newsletter $newsletter)
    {
        return $newsletter->user_id == user_id() && $newsletter->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given newsletter.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Newsletter $newsletter)
    {
        if ($authUser->canDo('newsletter.newsletter.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given newsletter.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Newsletter $newsletter)
    {
        if ($authUser->canDo('newsletter.newsletter.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
