<?php

namespace Larayellow\Newsletter\Providers;

use Illuminate\Support\ServiceProvider;
use Larayellow\Newsletter\Newsletter;

class NewsletterServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'newsletter');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'newsletter');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Larayellow\Newsletter\Providers\AuthServiceProvider::class);
        $this->app->register(\Larayellow\Newsletter\Providers\RouteServiceProvider::class);
        // $this->app->register(\Larayellow\Newsletter\Providers\EventServiceProvider::class);
        // $this->app->register(\Larayellow\Newsletter\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('larayellow.newsletter', function($app)
        {
            return $this->app->make(Newsletter::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
                // Bind Newsletter to repository
        $this->app->bind(
            'Larayellow\Newsletter\Interfaces\NewsletterRepositoryInterface',
            \Larayellow\Newsletter\Repositories\Eloquent\NewsletterRepository::class
        );
    }


    /**
     * Merges user's and newsletter's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'larayellow.newsletter'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Larayellow\Newsletter\Commands\Newsletter::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['larayellow.newsletter'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('larayellow/newsletter.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/newsletter')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/newsletter')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
